Mockintosh Control Plane

Docs
Pick any endpoint below and use "Try it out" button to send the request

| Request Count | Avg. Response Time | Response Codes

Enable tag:

Below is the config template for requests that are missing in Mockintosh config: Enabled

Enable Traffic Log

Select traffic entry from the left sidebar...

- Request Headers

- Request Body {</>} [+/-]

Response: 200

- Response Headers

- Response Body {</>} [+/-]

Async actors appear if config contains services of type kafka/amqp/redis.

### Producers

Actor #0: The name of it Produced!

Queue Name: somequeue1

Last Produced: 2021-01-01T12:00:00

Message Count: 1

### Consumers

Actor #0: The name of it

Queue Name: somequeue1

Last Consumed: 2021-01-01T12:00:00

Message Count: 0

##### Modal title